fdividef

产品支持情况

  • Ascend 950PR&950DT系列产品:支持
  • Atlas A3系列产品:不支持
  • Atlas A2系列产品:不支持
  • Atlas 200I/500 A2推理产品:不支持
  • Atlas推理系列产品AI Core:不支持
  • Atlas推理系列产品Vector Core:不支持
  • Atlas训练系列产品:不支持

功能说明

头文件路径为:"simt_api/math_functions.h"。

获取两个输入数据相除的结果。

函数原型

inline float fdividef(float x, float y)

参数说明

表1 参数说明

参数名 输入/输出 描述
x 输入 源操作数。
y 输入 源操作数。

返回值说明

两个输入数据相除的结果。

  • 当x为正数,y为0.0时,返回值为+inf。
  • 当x为负数,y为0.0时,返回值为-inf。
  • 当x为0.0,y为0.0时,返回值为nan。
  • 当x、y任意一个为nan时,返回值为nan。

约束说明

本接口受编译选项--cce-use-fast-math的影响。

  • --cce-use-fast-math=true:开启快速计算模式,不支持Subnormal场景的低精度除法计算,处于Subnormal范围内的输入和输出值,都会被刷新为保留符号的0。
  • --cce-use-fast-math=false:支持Subnormal场景的高精度除法计算。

调用示例

  • SIMT编程场景:

    #include "simt_api/math_functions.h"
    
    __global__ __launch_bounds__(256) void compute_fdividef(float *result, const float *x, const float *y, uint32_t count)
    {
        const uint32_t idx = blockIdx.x * blockDim.x + threadIdx.x;
        if (idx >= count) {
            return;
        }
        result[idx] = fdividef(x[idx], y[idx]);
    }
    
  • SIMD与SIMT混合编程场景:

    #include "simt_api/math_functions.h"
    
    __simt_vf__ __launch_bounds__(256) inline void compute_fdividef_vf(__gm__ float *result, __gm__ const float *x, __gm__ const float *y, uint32_t count)
    {
        const uint32_t idx = blockIdx.x * blockDim.x + threadIdx.x;
        if (idx >= count) {
            return;
        }
        result[idx] = fdividef(x[idx], y[idx]);
    }
    
    __global__ __vector__ void run_fdividef(__gm__ float *result, __gm__ const float *x, __gm__ const float *y, uint32_t count)
    {
        asc_vf_call<compute_fdividef_vf>(dim3(256), result, x, y, count);
    }
    

输入输出示例如下:

x:0.25, 0.75, 1.25, 1.75
y:1.5, 2.5, 3.5, 4.5
result: 0.1666667 0.3 0.3571429 0.3888889